@@ -57,10 +57,10 @@ impl<'a> Menu<'a> {
             None => write!(f, "<{}>", tag)?,
         }
         if let Some(label) = self.label.as_ref() {
-            label.write_as_tag(f, "attribute name='label'")?;
+            label.write_as_tag(f, "attribute", "name='label'")?;
         }
         if let Some(icon) = self.icon.as_deref() {
-            write!(f, "<attribute name='icon'>{}</attribute", encode_minimal(icon))?;
+            write!(f, "<attribute name='icon'>{}</attribute>", encode_minimal(icon))?;
         }
         for section in &self.sections {
             write!(f, "{}", section)?;
@@ -98,13 +98,13 @@ impl<'a> Display for MenuSection<'a> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f, "<section>")?;
         if let Some(label) = self.label.as_ref() {
-            label.write_as_tag(f, "attribute name='label'")?;
+            label.write_as_tag(f, "attribute", "name='label'")?;
         }
         if let Some(display_hint) = self.display_hint.as_deref() {
-            write!(f, "<attribute name='display-hint'>{}</attribute", encode_minimal(display_hint))?;
+            write!(f, "<attribute name='display-hint'>{}</attribute>", encode_minimal(display_hint))?;
         }
         if let Some(text_direction) = self.text_direction.as_deref() {
-            write!(f, "<attribute name='text-direction'>{}</attribute", encode_minimal(text_direction))?;
+            write!(f, "<attribute name='text-direction'>{}</attribute>", encode_minimal(text_direction))?;
         }
         for item in &self.items {
             write!(f, "{}", item)?;
@@ -160,27 +160,27 @@ impl<'a> Display for MenuItem<'a> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "<item>")?;
 
-        self.label.write_as_tag(f, "attribute name='label'")?;
+        self.label.write_as_tag(f, "attribute", "name='label'")?;
 
-        write!(f, "<attribute name='action'>{}</attribute", encode_minimal(&self.action))?;
+        write!(f, "<attribute name='action'>{}</attribute>", encode_minimal(&self.action))?;
 
         if let Some(target) = self.target.as_deref() {
-            write!(f, "<attribute name='target'>{}</attribute", encode_minimal(target))?;
+            write!(f, "<attribute name='target'>{}</attribute>", encode_minimal(target))?;
         }
         if let Some(icon) = self.icon.as_deref() {
-            write!(f, "<attribute name='icon'>{}</attribute", encode_minimal(icon))?;
+            write!(f, "<attribute name='icon'>{}</attribute>", encode_minimal(icon))?;
         }
         if let Some(verb_icon) = self.verb_icon.as_deref() {
-            write!(f, "<attribute name='verb-icon'>{}</attribute", encode_minimal(verb_icon))?;
+            write!(f, "<attribute name='verb-icon'>{}</attribute>", encode_minimal(verb_icon))?;
         }
         if let Some(submenu_action) = self.submenu_action.as_deref() {
-            write!(f, "<attribute name='submenu-action'>{}</attribute", encode_minimal(submenu_action))?;
+            write!(f, "<attribute name='submenu-action'>{}</attribute>", encode_minimal(submenu_action))?;
         }
         if let Some(hidden_when) = self.hidden_when.as_deref() {
-            write!(f, "<attribute name='hidden-when'>{}</attribute", encode_minimal(hidden_when))?;
+            write!(f, "<attribute name='hidden-when'>{}</attribute>", encode_minimal(hidden_when))?;
         }
         if let Some(custom) = self.custom.as_deref() {
-            write!(f, "<attribute name='custom'>{}</attribute", encode_minimal(custom))?;
+            write!(f, "<attribute name='custom'>{}</attribute>", encode_minimal(custom))?;
         }
 
         write!(f, "</item>")
@@ -297,7 +297,7 @@ impl Property<'_> {
         f: &mut fmt::Formatter<'_>
     ) -> fmt::Result {
         match self {
-            Self::Translatable(string) => string.write_as_tag(f, &format!(r#"<property name="{}""#, encode_attribute(name)))?,
+            Self::Translatable(string) => string.write_as_tag(f, "<property", &format!(r#"name="{}""#, encode_attribute(name)))?,
             Self::String(string) => write!(f, r#"<property name="{}">{}"#, encode_attribute(name), encode_minimal(string))?,
             Self::Bool(boolean) => write!(f, r#"<property name="{}">{}"#, encode_attribute(name), boolean)?,
             Self::Integer(integer) => write!(f, r#"<property name="{}">{}"#, encode_attribute(name), integer)?,
@@ -353,14 +353,15 @@ pub struct Translatable<'a> {
 }
 
 impl<'a> Translatable<'a> {
-    pub fn write_as_tag(&self, f: &mut fmt::Formatter, tag: &str) -> fmt::Result {
-        write!(
-            f,
-            r#"<{tag} translatable="true", context="{context}", comment="{comment}">{translatable}</{tag}>"#,
-            tag=tag,
-            context=encode_minimal(self.context.as_deref().unwrap_or_default()),
-            comment=encode_minimal(self.comment.as_deref().unwrap_or_default()),
-            translatable=self.translatable,
-        )
+    pub fn write_as_tag(&self, f: &mut fmt::Formatter, tag: &str, tag_attr: &str,) -> fmt::Result {
+        write!(f, r#"<{} translatable="true" {}"#, tag, tag_attr)?;
+        if let Some(context) = self.context.as_deref() {
+            write!(f, "context='{}'", encode_attribute(context))?;
+        }
+        if let Some(comment) = self.comment.as_deref() {
+            write!(f, "comment='{}'", encode_attribute(comment))?;
+        }
+        write!(f, ">{}", encode_minimal(&self.translatable))?;
+        write!(f, "</{}>", tag)
     }
 }
